package org.jboss.test.singletonservice;

import org.jboss.as.server.ServerEnvironment;
import org.jboss.msc.inject.Injector;
import org.jboss.msc.service.*;
import org.jboss.msc.value.InjectedValue;

import java.util.concurrent.atomic.AtomicBoolean;
import java.util.logging.Logger;

/**
 * Created with IntelliJ IDEA.
 * User: jkudrnac
 */
public class TestingSingletonService implements Service<String> {

    private AtomicBoolean started = new AtomicBoolean(false);
    public static final ServiceName SERVICE_NAME = ServiceName.JBOSS.append("test", "myservice");
    private final InjectedValue<ServerEnvironment> env = new InjectedValue<ServerEnvironment>();
    private static final Logger LOGGER = Logger.getLogger(TestingSingletonService.class.getCanonicalName());
    private String nodeName;

    @Override
    public String getValue() {
        if (!started.get()) {
            throw new IllegalStateException();
        }
        return this.nodeName;
    }

    @Override
    public void stop(StopContext stopContext) {
        if (!started.compareAndSet(true, false)) {
            LOGGER.warning("The service '" + this.getClass().getName() + "' is not active!");
        } else {
            LOGGER.info("Stop service '" + this.getClass().getName() + "'");
        }
    }

    @Override
    public void start(StartContext startContext) throws StartException {
        if (!started.compareAndSet(false, true)) {
            throw new StartException("The service is still started!");
        }
        LOGGER.info("Start service '" + this.getClass().getName() + "'");
        this.nodeName = this.env.getValue().getNodeName();
    }

    public Injector<ServerEnvironment> getEnvInjector() {
        return this.env;
    }
}
